@@ -52,7 +52,7 @@ has 'species'         => ( is => 'ro', isa => 'Str',  default => 'species' );
 has 'strain'          => ( is => 'ro', isa => 'Str',  default => 'strain' );
 has 'contig_uniq_id'  => ( is => 'ro', isa => 'Str',  default => 'gnl' );
 has 'kingdom'         => ( is => 'rw', isa => 'Str',  default => 'Bacteria' );
-has 'gcode'           => ( is => 'ro', isa => 'Int',  default => 0 );
+has 'gcode'           => ( is => 'ro', isa => 'Int',  default => 11 );
 has 'gram'            => ( is => 'ro', isa => 'Str',  default => '' );
 has 'usegenus'        => ( is => 'rw', isa => 'Bool', default => 0 );
 has 'proteins'        => ( is => 'ro', isa => 'Str',  default => '' );
@@ -64,6 +64,7 @@ has 'rfam'            => ( is => 'ro', isa => 'Bool', default => 0 );
 has 'files_per_chunk' => ( is => 'ro', isa => 'Int',  default => 100 );
 has 'tempdir'         => ( is => 'ro', isa => 'Str',  default => '/tmp' );
 has 'cleanup_prod'    => ( is => 'ro', isa => 'Bool', default => 1 );
+has 'keep_original_order_and_names' => ( is => 'ro', isa => 'Bool', default => 0 );
 
 has 'exe'     => ( is => 'ro', isa => 'Str', default => 'PROKKA' );
 has 'version' => ( is => 'ro', isa => 'Str', default => '1.5' );
@@ -293,11 +294,19 @@ sub annotate {
             next;
         }
         $ncontig++;
-
+        my $id;
         # http://www.ncbi.nlm.nih.gov/genomes/static/Annotation_pipeline_README.txt
-        my $id = sprintf "contig%06d", $ncontig;
-        $id = "$contig_uniq_id|$centre|$id" if $centre;
-        $seq->display_id($id);
+        if($self->keep_original_order_and_names)
+        {
+            $id = $seq->display_id;
+        }
+        else
+        {
+            $id = sprintf "contig%06d", $ncontig;
+            $id = "$contig_uniq_id|$centre|$id" if $centre;
+            $seq->display_id($id);
+        }
+        
         my $s = $seq->seq;
         $s = uc($s);
         $s =~ s/[^ACTG]/N/g;
@@ -305,6 +314,7 @@ sub annotate {
         $seq->desc(undef);
         $fout->write_seq($seq);
         $seq{$id}{DNA} = $seq;
+        $seq{$id}{order} = $ncontig;
     }
     $self->msg("Wrote $ncontig contigs");
 
@@ -643,7 +653,8 @@ sub annotate {
               {
                 DB  => "$dbdir/hmm/$name.hmm",
                 SRC => "protein motif:$name:",
-                FMT => 'hmmer3',
+                FMT => 'hmmer',
+                VERSION => 3,
                 CMD => $HMMER3CMD,
               };
         }
@@ -728,7 +739,7 @@ sub annotate {
 
                     for ( my $j = $slice_size * $i ; $j < @cds_counter && $j < $slice_size * ( $i + 1 ) ; $j++ ) {
                         my $pid = $cds_counter[$j];
-                        my $bls = Bio::SearchIO->new( -file => "$tempdir/$pid.seq.out", -format => $db->{FMT} );
+                        my $bls = Bio::SearchIO->new( -file => "$tempdir/$pid.seq.out", -format => $db->{FMT}, -version => $db->{VERSION} );
                         my $res = $bls->next_result or next;
                         my $hit = $res->next_hit or next;
                         my ( $prod, $gene, $EC ) = ( $hit->description, '', '' );
@@ -917,8 +928,18 @@ sub annotate {
     if ( scalar keys %seq ) {
         print $gff_fh "##FASTA\n";
         my $seqio = Bio::SeqIO->new( -fh => $gff_fh, -format => 'fasta' );
-        for my $sid ( sort keys %seq ) {
-            $seqio->write_seq( $seq{$sid}{DNA} );
+        
+        if($self->keep_original_order_and_names)
+        {
+          for my $sid ( sort {$seq{$a}{order} <=> $seq{$b}{order} } keys %seq ) {
+              $seqio->write_seq( $seq{$sid}{DNA} );
+          }
+        }
+        else
+        {
+          for my $sid ( sort keys %seq ) {
+              $seqio->write_seq( $seq{$sid}{DNA} );
+          }
         }
     }
 
@@ -1029,13 +1050,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bio::AutomatedAnnotation::Prokka - Prokka class for bacterial annotation
 
 =head1 VERSION
 
-version 1.133090
+version 1.182680
 
 =head1 SYNOPSIS
 
